aboutsummaryrefslogtreecommitdiff
path: root/lib/hostip.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/hostip.c')
-rw-r--r--lib/hostip.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/lib/hostip.c b/lib/hostip.c
index 1a5711f55..a62e361c4 100644
--- a/lib/hostip.c
+++ b/lib/hostip.c
@@ -598,7 +598,7 @@ int Curl_resolv_timeout(struct connectdata *conn,
if(timeout)
infof(conn->data, "timeout on name lookup is not supported\n");
#else
- (void)timeout; /* timeout not used with an async resolver */
+ (void)timeoutms; /* timeoutms not used with an async resolver */
#endif
#endif /* USE_ALARM_TIMEOUT */